@@ -6,15 +6,20 @@ namespace   // the anonymous namespace can be used here
     Arg::LongOption longOptions[] =
     {
         Arg::LongOption("config", 'c'),
+
+        Arg::LongOption("conntrack-command", Arg::Required),
+
         Arg::LongOption("conntrack-path", Arg::Required),
-        Arg::LongOption("no-daemon", Arg::None),
+        Arg::LongOption("conntrack-restart", Arg::Required),
         Arg::LongOption("help", 'h'),
+        Arg::LongOption("no-daemon", Arg::None),
         Arg::LongOption("no-syslog", Arg::None),
-        Arg::LongOption("stdout", 's'),
         Arg::LongOption("pid-file", 'p'),
-        Arg::LongOption("syslog-tag", Arg::Required),
+        Arg::LongOption("protocol", Arg::Required),
+        Arg::LongOption("stdout", 's'),
         Arg::LongOption("syslog-facility", Arg::Required),
         Arg::LongOption("syslog-priority", Arg::Required),
+        Arg::LongOption("syslog-tag", Arg::Required),
         Arg::LongOption("time", 't'),
         Arg::LongOption("verbose", Arg::None),
         Arg::LongOption("version", 'v'),
