@@ -7,19 +7,17 @@ void NatFork::childProcess()
     if (d_options.daemon())
         prepareDaemon();
 
-    OFdStream out(d_pipe.writeFd());        // the message to the parent
-
     try
     {
         if (d_mode == CONNTRACK)
         {
             Conntrack conntrack(d_stdMsg);
-            conntrack.run(out);
+            conntrack.run();
         }
         else 
         {
             Devices devices(d_stdMsg);
-            devices.run(out);
+            devices.run();
         }
     }
     catch (exception const &err)        // errors at Conntrack or Devices
@@ -28,7 +26,7 @@ void NatFork::childProcess()
             throw;                      // rethrow the exception
 
         d_stdMsg << err.what() << endl;
-        out << 1 << endl;               // The daemon can't start:
+//        out << 1 << endl;               // The daemon can't start:
                                         // inform via the pipe
     }
 
