@@ -1,11 +1,15 @@
 #include "options.ih"
 
 char const Options::s_defaultConfigPath[]       = "/etc/natlog.conf";
-char const Options::s_defaultConntrackPath[]    = "/usr/sbin/conntrack";
+
+char const Options::s_defaultConntrackCommand[]    = "/usr/sbin/conntrack";
+char const Options::s_defaultConntrackArgs[]    = 
+                                        " -E -n -o timestamp -e NEW,DESTROY";
+
 char const Options::s_defaultSyslogIdent[]      = "NATLOG";
 char const Options::s_defaultSyslogFacility[]   = "DAEMON";
 char const Options::s_defaultSyslogPriority[]   = "NOTICE";
-char const Options::s_defaultPIDfile[]          = "/var/run/natlog.pid";
+char const Options::s_defaultPIDfile[]          = "/run/natlog.pid";
 
 unordered_map<string, Options::Time> const Options::s_time = 
     {
